==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_results/mp7836_001/MP7836_GetCustomerRentalDefault_001_Result.java <==

package net.datastream.schemas.mp_results.mp7836_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.customerrentaldefault_001.CustomerRentalDefault;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/CustomerRentalDefault_001}CustomerRentalDefault"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7836_GetCustomerRentalDefault_001_Result")
public class MP7836_GetCustomerRentalDefault_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7836_GetCustomerRentalDefault_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP7836_GetCustomerRentalDefault_001_Result.ResultData }
     *     
     */
    public MP7836_GetCustomerRentalDefault_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7836_GetCustomerRentalDefault_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7836_GetCustomerRentalDefault_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/CustomerRentalDefault_001}CustomerRentalDefault"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "customerRentalDefault"
    })
    public static class ResultData {

        @XmlElement(name = "CustomerRentalDefault", namespace = "http://schemas.datastream.net/MP_entities/CustomerRentalDefault_001", required = true)
        protected CustomerRentalDefault customerRentalDefault;

        /**
         * Gets the value of the customerRentalDefault property.
         * 
         * @return
         *     possible object is
         *     {@link CustomerRentalDefault }
         *     
         */
        public CustomerRentalDefault getCustomerRentalDefault() {
            return customerRentalDefault;
        }

        /**
         * Sets the value of the customerRentalDefault property.
         * 
         * @param value
         *     allowed object is
         *     {@link CustomerRentalDefault }
         *     
         */
        public void setCustomerRentalDefault(CustomerRentalDefault value) {
            this.customerRentalDefault = value;
        }

    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_results/mp7836_001/MP7836_GetCustomerRentalDefault_001_Result.java <==

package net.datastream.schemas.mp_results.mp7836_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.customerrentaldefault_001.CustomerRentalDefault;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="ResultData">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <sequence>
 *                   <element ref="{http://schemas.datastream.net/MP_entities/CustomerRentalDefault_001}CustomerRentalDefault"/>
 *                 </sequence>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7836_GetCustomerRentalDefault_001_Result")
public class MP7836_GetCustomerRentalDefault_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7836_GetCustomerRentalDefault_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP7836_GetCustomerRentalDefault_001_Result.ResultData }
     *     
     */
    public MP7836_GetCustomerRentalDefault_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7836_GetCustomerRentalDefault_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7836_GetCustomerRentalDefault_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <sequence>
     *         <element ref="{http://schemas.datastream.net/MP_entities/CustomerRentalDefault_001}CustomerRentalDefault"/>
     *       </sequence>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "customerRentalDefault"
    })
    public static class ResultData {

        @XmlElement(name = "CustomerRentalDefault", namespace = "http://schemas.datastream.net/MP_entities/CustomerRentalDefault_001", required = true)
        protected CustomerRentalDefault customerRentalDefault;

        /**
         * Gets the value of the customerRentalDefault property.
         * 
         * @return
         *     possible object is
         *     {@link CustomerRentalDefault }
         *     
         */
        public CustomerRentalDefault getCustomerRentalDefault() {
            return customerRentalDefault;
        }

        /**
         * Sets the value of the customerRentalDefault property.
         * 
         * @param value
         *     allowed object is
         *     {@link CustomerRentalDefault }
         *     
         */
        public void setCustomerRentalDefault(CustomerRentalDefault value) {
            this.customerRentalDefault = value;
        }

    }

}
